@@ -25,15 +25,15 @@
 # environment. You need to have installed the packages py26-gtk and
 # py26-py2app.
 
-LIBPREFIX=$HOME/macports-10.5
-PYTHON=$LIBPREFIX/bin/python2.6
+LIBPREFIX=$HOME/macports-10.8
+PYTHON=$LIBPREFIX/bin/python2.7
 PKG_CONFIG=$LIBPREFIX/bin/pkg-config
 APP_NAME=Zenmap
 BASE=dist/$APP_NAME.app/Contents
 SCRIPT_DIR=`dirname "$0"`
 
 CC=${CC:-gcc}
-CFLAGS=${CFLAGS:--Wall}
+CFLAGS=${CFLAGS:--Wall -arch i386}
 
 echo "Running $0."
 
@@ -41,7 +41,7 @@ echo "Removing old build."
 rm -rf build dist
 
 echo "Compiling using py2app."
-$PYTHON setup.py py2app --no-strip
+$PYTHON setup.py py2app --arch=i386 --no-strip
 
 # Delete a library that causes compatibility problems with OS X 10.9.
 # http://seclists.org/nmap-dev/2013/q4/85
@@ -58,16 +58,13 @@ cp -R $LIBPREFIX/lib/gtk-2.0/$gtk_version/* $BASE/Resources/lib/gtk-2.0/$gtk_ver
 mkdir -p $BASE/Resources/etc/gtk-2.0
 cp $SCRIPT_DIR/gtkrc $BASE/Resources/etc/gtk-2.0/
 
-pango_version=`$PKG_CONFIG --variable=pango_module_version pango`
-echo "Copying Pango $pango_version files."
-mkdir -p $BASE/Resources/etc/pango
-cat > $BASE/Resources/etc/pango/pangorc.in <<EOF
-# This template is filled in at run time by the application.
-
-[PangoX]
-AliasFiles = \${RESOURCES}/etc/pango/pangox.aliases
-EOF
-cp $LIBPREFIX/etc/pango/pangox.aliases $BASE/Resources/etc/pango/
+echo "Updating paths in GTK+ .so files"
+ESCAPED_LIBPREFIX=$(echo $LIBPREFIX | sed 's/\([\/\\.]\)/\\\1/g')
+find $BASE/Resources/lib/gtk-2.0/$gtk_version/ -type f -name '*.so' | while read so; do
+  otool -L "$so" | awk "/$ESCAPED_LIBPREFIX/{print \$1}" | while read dep; do
+    install_name_tool -change $dep $(echo $dep | sed "s/$ESCAPED_LIBPREFIX\/lib/@executable_path\/..\/Frameworks/") "$so"
+  done
+done
 
 echo "Copying Fontconfig files."
 cp -R $LIBPREFIX/etc/fonts $BASE/Resources/etc/
@@ -75,7 +72,7 @@ cp -R $LIBPREFIX/etc/fonts $BASE/Resources/etc/
 sed -i "" 's/ *<dir>'$(echo "$LIBPREFIX" | sed -e 's/\([^a-zA-Z0-9]\)/\\\1/g')'\/share\/fonts<\/dir>//g' $BASE/Resources/etc/fonts/fonts.conf
 sed -i "" '/<cachedir>'$(echo "$LIBPREFIX" | sed -e 's/\([^a-zA-Z0-9]\)/\\\1/g')'\/var\/cache\/fontconfig<\/cachedir>/d' $BASE/Resources/etc/fonts/fonts.conf
 # Disable hinting to better match the Mac GUI.
-ln -sf ../conf.avail/10-unhinted.conf $BASE/Resources/etc/fonts/conf.d
+cp $LIBPREFIX/share/fontconfig/conf.avail/10-unhinted.conf $BASE/Resources/etc/fonts/conf.d
 
 echo "Renaming main Zenmap executable."
 mv $BASE/MacOS/$APP_NAME $BASE/MacOS/zenmap.bin
