@@ -3,7 +3,7 @@
 
 # ***********************IMPORTANT NMAP LICENSE TERMS************************
 # *                                                                         *
-# * The Nmap Security Scanner is (C) 1996-2014 Insecure.Com LLC. Nmap is    *
+# * The Nmap Security Scanner is (C) 1996-2015 Insecure.Com LLC. Nmap is    *
 # * also a registered trademark of Insecure.Com LLC.  This program is free  *
 # * software; you may redistribute and/or modify it under the terms of the  *
 # * GNU General Public License as published by the Free Software            *
@@ -94,8 +94,7 @@
 # *                                                                         *
 # * Source is provided to this software because we believe users have a     *
 # * right to know exactly what a program is going to do before they run it. *
-# * This also allows you to audit the software for security holes (none     *
-# * have been found so far).                                                *
+# * This also allows you to audit the software for security holes.          *
 # *                                                                         *
 # * Source code also allows you to port Nmap to new platforms, fix bugs,    *
 # * and add new features.  You are highly encouraged to send your changes   *
@@ -116,7 +115,7 @@
 # * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 # * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
 # * license file for more details (it's in a COPYING file included with     *
-# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
+# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING)        *
 # *                                                                         *
 # ***************************************************************************/
 
@@ -236,7 +235,7 @@ class my_install(install):
         # install.finalize_options when sys.prefix is "/usr/local" (our
         # default). Because we need the unchanged value later, remember it
         # here.
-        self.saved_prefix = self.prefix
+        self.saved_prefix = sys.prefix
         install.finalize_options(self)
 
     def run(self):
@@ -549,7 +548,7 @@ class my_uninstall(Command):
 # all the operations.
 COMMON_SETUP_ARGS = {
     'name': APP_NAME,
-    'license': 'Nmap License (http://nmap.org/book/man-legal.html)',
+    'license': 'Nmap License (https://nmap.org/book/man-legal.html)',
     'url': APP_WEB_SITE,
     'download_url': APP_DOWNLOAD_SITE,
     'author': 'Nmap Project',
